# Portions Copyright (C) 2010, Manfred Moitzi under a BSD licence

from unittest import TestCase

import xlrd2
from xlrd2 import open_workbook
from xlrd2.book import Book
from xlrd2.sheet import Sheet

from .base import from_this_dir

SHEETINDEX = 0
NROWS = 15
NCOLS = 13


class TestWorkbook(TestCase):
    sheetnames = ['PROFILEDEF', 'AXISDEF', 'TRAVERSALCHAINAGE',
                  'AXISDATUMLEVELS', 'PROFILELEVELS']

    def setUp(self):
        self.book = open_workbook(from_this_dir('profiles.xls'))

    def test_open_workbook(self):
        self.assertTrue(isinstance(self.book, Book))

    def test_nsheets(self):
        self.assertEqual(self.book.nsheets, 5)

    def test_sheet_by_name(self):
        for name in self.sheetnames:
            sheet = self.book.sheet_by_name(name)
            self.assertTrue(isinstance(sheet, Sheet))
            self.assertEqual(name, sheet.name)

    def test_sheet_by_index(self):
        for index in range(5):
            sheet = self.book.sheet_by_index(index)
            self.assertTrue(isinstance(sheet, Sheet))
            self.assertEqual(sheet.name, self.sheetnames[index])

    def test_sheets(self):
        sheets = self.book.sheets()
        for index, sheet in enumerate(sheets):
            self.assertTrue(isinstance(sheet, Sheet))
            self.assertEqual(sheet.name, self.sheetnames[index])

    def test_sheet_names(self):
        self.assertEqual(self.sheetnames, self.book.sheet_names())

    def test_getitem_ix(self):
        sheet = self.book[SHEETINDEX]
        self.assertNotEqual(xlrd2.empty_cell, sheet.cell(0, 0))
        self.assertNotEqual(xlrd2.empty_cell, sheet.cell(NROWS - 1, NCOLS - 1))

    def test_getitem_name(self):
        sheet = self.book[self.sheetnames[SHEETINDEX]]
        self.assertNotEqual(xlrd2.empty_cell, sheet.cell(0, 0))
        self.assertNotEqual(xlrd2.empty_cell, sheet.cell(NROWS - 1, NCOLS - 1))

    def test_iter(self):
        sheets = [sh.name for sh in self.book]
        self.assertEqual(sheets, self.sheetnames)



# Portions Copyright (C) 2010, Manfred Moitzi under a BSD licence

from unittest import TestCase

from xlrd2 import open_workbook
from xlrd2.book import Book

from .base import from_this_dir


class TestSharedStringsAltLocation(TestCase):

    def setUp(self):
        self.book = open_workbook(from_this_dir('sharedstrings_alt_location.xlsx'))

    def test_open_workbook(self):
        # Without the handling of the alternate location for the sharedStrings.xml file, this would pop.
        self.assertTrue(isinstance(self.book, Book))



from unittest import TestCase

import xlrd2

from .base import from_this_dir


class TestIgnoreWorkbookCorruption(TestCase):

    def test_not_corrupted(self):
        with self.assertRaises(Exception) as context:
            xlrd2.open_workbook(from_this_dir('corrupted_error.xls'))
        self.assertTrue('Workbook corruption' in str(context.exception))

        xlrd2.open_workbook(from_this_dir('corrupted_error.xls'), ignore_workbook_corruption=True)



from setuptools import setup
import os

from xlrd2.info import __VERSION__

project_dir = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(project_dir, 'README.md')) as f:
    long_description = f.read()

setup(
    name = 'xlrd2',
    version = __VERSION__,
    author = 'Amirreza Niakanlahiji',
    author_email = 'aniak2@uis.edu',
    packages = ['xlrd2'],
    scripts = [
        'scripts/runxlrd2.py',
    ],
    long_description_content_type="text/markdown",
    description = (
        'Library for developers to extract data from '
        'Microsoft Excel legacy spreadsheet files (xls)'
    ),
    long_description = long_description,
    platforms = ["Any platform -- don't need Windows"],
    license = 'Apache License 2.0',
    keywords = ['xls', 'excel', 'spreadsheet', 'workbook'],
    classifiers = [
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Operating System :: OS Independent',
        'Topic :: Database',
        'Topic :: Office/Business',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
)
